==> haskell-doctemplates-0.2.2.1-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-CUNvomwqoYcDbmeeXzOyEK
key: doctemplates-0.2.2.1-CUNvomwqoYcDbmeeXzOyEK
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: 178bfb4d3ac7ded0ac911dcd8fe1fab9
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.3/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-CUNvomwqoYcDbmeeXzOyEK
depends:
    aeson-1.4.2.0-g6WW26hc5QFrgotIu9IXt base-4.12.0.0
    blaze-html-0.9.1.1-BgfYHwfc8MB4VF6u8ZvMhm
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.2.2.1-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-5RfYIOyBrkeCp1mJ1zJZJS
key: doctemplates-0.2.2.1-5RfYIOyBrkeCp1mJ1zJZJS
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: 55a1bcf6fa3f3bf8522c8ff1be6bb0a7
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.3/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-5RfYIOyBrkeCp1mJ1zJZJS
depends:
    aeson-1.4.2.0-4owspgDf5bB3ddpBjmAUar base-4.12.0.0
    blaze-html-0.9.1.1-LRzDCwXHdqc5c8RG20bUrB
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
